# -*- coding:utf-8 -*-

import pymysql
import pandas as pd
from mysql_read import MysqlConfig


class MysqlConnect:

    def __init__(self):
        """连接数据库"""
        self.db = MysqlConfig()
        db_host = self.db.connect("DB_HOST")
        db_username = self.db.connect("DB_USERNAME")
        db_password = self.db.connect("DB_PASSWORD")
        db_database = self.db.connect("DB_DATABASE")
        db_port = int(self.db.connect("DB_PORT"))
        db_charset = self.db.connect("DB_CHARSET")
        self.conn = pymysql.connect(host=db_host, user=db_username, password=db_password, db=db_database,
                                    port=db_port, charset=db_charset)
        self.cursor = self.conn.cursor()

    def execute_sql(self, sql, data):
        """执行操作数据的相关sql"""
        try:
            self.cursor.execute(sql % data)
            self.conn.commit()
        except:
            # 发生错误时回滚
            print('Error: insert or update failure')
            self.conn.rollback()

    def search_all(self, sql, data):
        """执行查询sql"""
        self.cursor.execute(sql % data)
        return self.cursor.fetchall()

    def search_one(self, sql, data):
        """执行查询sql"""
        self.cursor.execute(sql % data)
        return self.cursor.fetchone()

    def panda_search(self, sql, data):
        """执行查询sql"""
        result = pd.read_sql(sql % data, self.conn)
        return result

    def close_mysql(self):
        """关闭数据库连接"""
        self.cursor.close()
        self.conn.close()


